@@ -179,13 +179,16 @@ widen <- function(X){
 }
 
 
-# Convert iCodes to iNames
-#
-# @param coin A coin
-# @param iCodes A vector of iCodes
-#
-# @return Vector of iNames
-codes2names <- function(coin, iCodes){
+#' Convert iCodes to iNames
+#'
+#' @param coin A coin
+#' @param iCodes A vector of iCodes
+#'
+#' @return Vector of iNames
+#' @export
+icodes_to_inames <- function(coin, iCodes){
+
+  stopifnot(is.coin(coin))
 
   iMeta <- coin$Meta$Ind
 
@@ -195,6 +198,25 @@ codes2names <- function(coin, iCodes){
 
 }
 
+#' Convert uCodes to uNames
+#'
+#' @param coin A coin
+#' @param uCodes A vector of uCodes
+#'
+#' @return Vector of uNames
+#' @export
+ucodes_to_unames <- function(coin, uCodes){
+
+  stopifnot(is.coin(coin))
+
+  uMeta <- coin$Meta$Unit
+
+  stopifnot(all(uCodes %in% uMeta$uCode))
+
+  uMeta$uName[match(uCodes, uMeta$uCode)]
+
+}
+
 
 # Splits data frame into numeric and non-numeric columns
 #
@@ -262,3 +284,22 @@ remove_duplicate_corrs <- function(X, cols){
   X[!duplicated_rows, ]
 
 }
+
+# convert integer columns to numeric (intended for iData)
+df_int_2_numeric <- function(X){
+
+  # convert integer cols to numeric (iData)
+  rnames <- row.names(X)
+  col_names <- names(X)
+  X <- lapply(col_names, function(col_name){
+    x <- X[[col_name]]
+    if(is.integer(x)){
+      message("iData column '", col_name, "' converted from integer to numeric.")
+      as.numeric(x)
+    } else x
+  }) |> as.data.frame()
+  row.names(X) <- rnames
+  names(X) <- col_names
+  X
+
+}
